@@ -418,12 +418,12 @@ void ModelTest::checkChildren(const QModelIndex &parent, int currentDepth)
         }
 
         // General Purpose roles that should return a QColor
-        QVariant colorVariant = model->data(model->index(0, 0), Qt::BackgroundColorRole);
+        QVariant colorVariant = model->data(model->index(0, 0), Qt::BackgroundRole);
         if (colorVariant.isValid()) {
             Q_ASSERT(variant.canConvert(QMetaType::QColor));
         }
 
-        colorVariant = model->data(model->index(0, 0), Qt::TextColorRole);
+        colorVariant = model->data(model->index(0, 0), Qt::ForegroundRole);
         if (colorVariant.isValid()) {
             Q_ASSERT(variant.canConvert(QMetaType::QColor));
         }
